Crate minidx_vis

Crate minidx_vis 

Modules

anim
prelude

Structs

ParamBox
Describes the sizing of the cell for a single parameter.
ParamVisOpts
Options for rendering a set of parameters.
VisFont
A loaded font for use in rastering text during visualization.

Enums

ParamScale
How to scale the representation of parameters relative to each other.

Traits

VisualizableNetwork
Some composition of parameters which can be visualized.