Modules
Structs
- Param
Box - Describes the sizing of the cell for a single parameter.
- Param
VisOpts - Options for rendering a set of parameters.
- VisFont
- A loaded font for use in rastering text during visualization.
Enums
- Param
Scale - How to scale the representation of parameters relative to each other.
Traits
- Visualizable
Network - Some composition of parameters which can be visualized.